cgdat.qt_ui — CGDAT 2.0.0-2-g2917492 documentation

# cgdat.qt_ui

This package contains all the QT python classes that were autogenearted out of the .ui files by the PyQt5.uic.pyuic module. It contains the following components:

> - About_ui.
> - cgdat_ui.
> - output_settings_ui.
> - progress_dialog_ui.
> - import_dialog_ui.

Note

Because these files were autogenerated no sphinx documentation is available for them. Go to the pyqt documentation for more information.